@@ -302,21 +302,22 @@ brasero_io_return_result_idle (gpointer callback_data)
 	BraseroIOResultCallbackData *data;
 	BraseroIOJobResult *result;
 	BraseroIOPrivate *priv;
+	guint results_id;
 	int i;
 
 	priv = BRASERO_IO_PRIVATE (self);
 
+	g_mutex_lock (priv->lock);
+
+	/* Put that to 0 for now so that a new idle call will be scheduled while
+	 * we are in the loop. That way if we block the other one will be able 
+	 * to deliver the results. */
+	results_id = priv->results_id;
+	priv->results_id = 0;
+
 	/* Return several results at a time that can be a huge speed gain.
-	 * What should be the value that provides speed and responsiveness. */
-	for (i = 0; i < 25; i ++) {
-		g_mutex_lock (priv->lock);
-
-		if (!priv->results) {
-			priv->results_id = 0;
-			g_mutex_unlock (priv->lock);
-			return FALSE;
-		}
-
+	 * What should be the value that provides speed and responsiveness? */
+	for (i = 0; priv->results && i < 25; i ++) {
 		result = priv->results->data;
 		priv->results = g_slist_remove (priv->results, result);
 
@@ -336,9 +337,20 @@ brasero_io_return_result_idle (gpointer callback_data)
 						       result->base->destroy,
 						       FALSE);
 		brasero_io_job_result_free (result);
+
+		g_mutex_lock (priv->lock);
 	}
 
-	return TRUE;
+	if (!priv->results_id && priv->results) {
+		/* There are still results and no idle call is scheduled so we
+		 * have to restart ourselves to make sure we empty the queue */
+		priv->results_id = results_id;
+		g_mutex_unlock (priv->lock);
+		return TRUE;
+	}
+
+	g_mutex_unlock (priv->lock);
+	return FALSE;
 }
 
 static void
@@ -1256,7 +1268,7 @@ brasero_io_add_playlist_entry_parsed_cb (TotemPlParser *parser,
 }
 
 static void
-brasero_io_start_end_playlist_cb (TotemPlParser *parser,
+brasero_io_start_playlist_cb (TotemPlParser *parser,
 				  const gchar *uri,
 				  GHashTable *metadata,
 				  BraseroIOPlaylist *data)
@@ -1282,11 +1294,7 @@ brasero_io_parse_playlist_get_uris (const gchar *uri,
 	parser = totem_pl_parser_new ();
 	g_signal_connect (parser,
 			  "playlist-started",
-			  G_CALLBACK (brasero_io_start_end_playlist_cb),
-			  playlist);
-	g_signal_connect (parser,
-			  "playlist-ended",
-			  G_CALLBACK (brasero_io_start_end_playlist_cb),
+			  G_CALLBACK (brasero_io_start_playlist_cb),
 			  playlist);
 	g_signal_connect (parser,
 			  "entry-parsed",
